Class: AutomationHelpers::Drivers::V4::Local

Inherits:
Object
  • Object
show all
Defined in:
lib/automation_helpers/drivers/v4/local.rb

Overview

The Local Driver that will spin up and run on your machine (Without connecting to any grid)

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(browser, options = Options.for(browser)) ⇒ Local

Initial setup options

  • browser (required) - When instantiating, the first argument must be the symbol that represents what browser to use
  • options (optional) -> You can instantiate an Options payload that can be used when registering your driver


20
21
22
23
# File 'lib/automation_helpers/drivers/v4/local.rb', line 20

def initialize(browser, options = Options.for(browser))
  @browser = browser
  @options = options
end

Instance Attribute Details

#browserObject (readonly)

Returns the value of attribute browser.



14
15
16
# File 'lib/automation_helpers/drivers/v4/local.rb', line 14

def browser
  @browser
end

#optionsObject (readonly)

Returns the value of attribute options.



14
15
16
# File 'lib/automation_helpers/drivers/v4/local.rb', line 14

def options
  @options
end

Instance Method Details

#registerNil

Register a new driver with the default selenium name for use locally

Returns:

  • (Nil)


28
29
30
31
32
33
34
35
36
37
# File 'lib/automation_helpers/drivers/v4/local.rb', line 28

def register
  Capybara.register_driver :selenium do |app|
    Capybara::Selenium::Driver.new(
      app,
      browser: browser,
      service: service,
      options: options
    )
  end
end