Class: AutomationHelpers::Drivers::V4::Options
- Inherits:
-
Object
- Object
- AutomationHelpers::Drivers::V4::Options
- Defined in:
- lib/automation_helpers/drivers/v4/options.rb
Overview
The Options object for the relevant browser whose driver you are configuring
Initial setup options
- ENV (optional) - Whether you want your browser (only applicable ones) to run headless or not
Class Method Summary collapse
-
.for(browser) ⇒ Selenium::Webdriver::Options
Returns the Options payload relevant to the browser specified to be passed to the driver instantiation.
Class Method Details
.for(browser) ⇒ Selenium::Webdriver::Options
Returns the Options payload relevant to the browser specified to be passed to the driver instantiation
19 20 21 22 23 24 25 26 27 28 |
# File 'lib/automation_helpers/drivers/v4/options.rb', line 19 def for(browser) case browser when :chrome; then when :firefox; then when :edge; then when :safari; then when :internet_explorer; then else {} end end |