Class: AutomationHelpers::Patches::CapybaraWindow
- Defined in:
- lib/automation_helpers/patches/capybara_window.rb
Overview
Fix the issue where you cannot close the first window in the handle array with #close_window
Fix the issue where you cannot close the first window in the handle array with #close_window