Class: HTTP::Cookie
- Inherits:
-
Object
- Object
- HTTP::Cookie
- Defined in:
- lib/automation_helpers/extensions/http-cookie/cookie.rb
Overview
Additional useful methods to extend the HTTP::Cookie class with
Instance Method Summary collapse
-
#to_h ⇒ Hash
A hashified representation of the cookie that will enable you to push it into Selenium Manager.
Instance Method Details
#to_h ⇒ Hash
A hashified representation of the cookie that will enable you to push it into Selenium Manager
11 12 13 14 15 16 17 18 19 |
# File 'lib/automation_helpers/extensions/http-cookie/cookie.rb', line 11 def to_h { name: name, value: value, path: path, secure: secure, expires: expires } end |