Class: HTTP::CookieJar
- Inherits:
-
Object
- Object
- HTTP::CookieJar
- Defined in:
- lib/automation_helpers/extensions/http-cookie/cookie_jar.rb
Overview
Additional useful methods to extend the HTTP::CookieJar class with
Instance Method Summary collapse
-
#cookie_named(name) ⇒ HTTP::Cookie?
The cookie that has the supplied name.
-
#include?(cookie_name) ⇒ Boolean
Whether the cookie jar contains the cookie with the supplied name.
Instance Method Details
#cookie_named(name) ⇒ HTTP::Cookie?
The cookie that has the supplied name
11 12 13 |
# File 'lib/automation_helpers/extensions/http-cookie/cookie_jar.rb', line 11 def (name) .detect { || .name == name } end |
#include?(cookie_name) ⇒ Boolean
Whether the cookie jar contains the cookie with the supplied name
18 19 20 |
# File 'lib/automation_helpers/extensions/http-cookie/cookie_jar.rb', line 18 def include?() .any? { || .name == } end |