Class: AutomationHelpers::Drivers::V4::Remote
- Inherits:
-
Object
- Object
- AutomationHelpers::Drivers::V4::Remote
- Defined in:
- lib/automation_helpers/drivers/v4/remote.rb
Overview
The Remote Driver that will connect to a dockerized self-hosted grid This expects the grid to be live and accepting node requests
Instance Method Summary collapse
-
#initialize(browser) ⇒ Remote
constructor
#### Initial setup options.
-
#register ⇒ Nil
Register a new driver with the default selenium name for use in a (localised), remote grid setup.
Constructor Details
#initialize(browser) ⇒ Remote
#### Initial setup options
-
browser (required) - When instantiating, the first argument must be the symbol that represents what browser to use
-
**ENV** (required) - The environment variable HUB_URL must be set to the actively running dockerized grid (By default this should be
http://hub:4444/wd/hub)
22 23 24 |
# File 'lib/automation_helpers/drivers/v4/remote.rb', line 22 def initialize(browser) @browser = browser end |
Instance Method Details
#register ⇒ Nil
Register a new driver with the default selenium name for use in a (localised), remote grid setup
29 30 31 32 33 34 35 36 37 38 |
# File 'lib/automation_helpers/drivers/v4/remote.rb', line 29 def register .register_driver :selenium do |app| ::Selenium::Driver.new( app, browser: :remote, capabilities: [browser_capabilities, ], url: hub_url ) end end |